@@ -9,6 +9,7 @@ import uuid
 from asyncio import Semaphore
 from collections.abc import AsyncGenerator
 from io import TextIOBase, StringIO
+from time import perf_counter_ns
 from typing import Tuple, Type, Optional
 
 import backoff
@@ -80,15 +81,21 @@ class AsRestError(ClientResponseError):
 
 
 def as_dump_response(*, response: ClientResponse, response_data=None, data=None,
-                     json=None, file: TextIOBase = None, dump_log: logging.Logger = None):
+                     json=None, file: TextIOBase = None, dump_log: logging.Logger = None,
+                     diff_ns: int = None):
     """
     Dump response object to log file
 
     :param response: HTTP request response
+    :param response_data:
+    :param data:
+    :param json:
     :param file: stream to dump to
     :type file: TextIOBase
     :param dump_log: logger to dump to
     :type dump_log: logging.Logger
+    :param diff_ns: time the request took (in ns)
+    :type diff_ns: int
     """
     if not log.isEnabledFor(logging.DEBUG):
         return
@@ -99,7 +106,8 @@ def as_dump_response(*, response: ClientResponse, response_data=None, data=None,
     for h in response.history:
         as_dump_response(response=h, file=output)
 
-    print(f'Request {response.status}[{response.reason}]: '
+    time_str = diff_ns is None and '' or f'({diff_ns / 1000000.0:.3f} ms)'
+    print(f'Request {response.status}[{response.reason}]{time_str}: '
           f'{response.request_info.method} {response.request_info.url}', file=output)
 
     # request headers
@@ -127,7 +135,7 @@ def as_dump_response(*, response: ClientResponse, response_data=None, data=None,
         print(f'  {k}: {response.headers[k]}', file=output)
     # dump response body
     if response_data:
-        print('  ---response body ---', file=output)
+        print('  --- response body ---', file=output)
         try:
             body = response_data
             if 'access_token' in body:
@@ -138,7 +146,7 @@ def as_dump_response(*, response: ClientResponse, response_data=None, data=None,
             pass
         for line in body.splitlines():
             print(f'  {line}', file=output)
-    print(' ---- end ----', file=output)
+    print(' --- end ---', file=output)
     if file is None:
         dump_log.debug(output.getvalue())
 
@@ -223,16 +231,9 @@ class AsRestSession(ClientSession):
         if headers:
             request_headers.update((k.lower(), v) for k, v in headers.items())
         async with self._sem:
-            async with self.request(method, url=url, headers=request_headers, data=data, json=json, **kwargs) as response:
-                try:
-                    response.raise_for_status()
-                except ClientResponseError as error:
-                    as_dump_response(response=response, data=data, json=json)
-                    # create a RestError based on HTTP error
-                    error = AsRestError(request_info=error.request_info,
-                                        history=error.history, status=error.status,
-                                        message=error.message, headers=error.headers)
-                    raise error
+            start = perf_counter_ns()
+            async with self.request(method, url=url, headers=request_headers,
+                                    data=data, json=json, **kwargs) as response:
                 # get response body as text or dict (parsed JSON)
                 ct = response.headers.get('Content-Type')
                 if not ct:
@@ -241,7 +242,16 @@ class AsRestSession(ClientSession):
                     response_data = await response.json()
                 else:
                     response_data = await response.text()
-                as_dump_response(response=response, data=data, json=json, response_data=response_data)
+                diff_ns = perf_counter_ns() - start
+                as_dump_response(response=response, data=data, json=json, response_data=response_data, diff_ns=diff_ns)
+                try:
+                    response.raise_for_status()
+                except ClientResponseError as error:
+                    # create a RestError based on HTTP error
+                    error = AsRestError(request_info=error.request_info,
+                                        history=error.history, status=error.status,
+                                        message=error.message, headers=error.headers)
+                    raise error
 
         return response, response_data
 
@@ -311,7 +321,7 @@ class AsRestSession(ClientSession):
         """
         return await self._rest_request('PATCH', *args, **kwargs)
 
-    async def follow_pagination(self, *, url: str, model: Type[ApiModel],
+    async def follow_pagination(self, url: str, model: Type[ApiModel] = None,
                                 params: dict = None,
                                 item_key: str = None, **kwargs) -> AsyncGenerator[ApiModel, None, None]:
         """
@@ -327,6 +337,13 @@ class AsRestSession(ClientSession):
         :type item_key: str
         :return: yields parsed objects
         """
+        def noop(x):
+            return x
+        if model is None:
+            model = noop
+        else:
+            model = model.parse_obj
+
         while url:
             log.debug(f'{self}.pagination: getting {url}')
             response, data = await self._request_w_response('GET', url=url, params=params, **kwargs)
@@ -337,6 +354,10 @@ class AsRestSession(ClientSession):
                 url = str(response.links['next']['url'])
             except KeyError:
                 url = None
+            else:
+                # TODO: remove workaround as soon as pagination URL issue gets fixed (WXCAPIBULK-27)
+                if len((pagination_fix := url.split('https,https:/'))) > 1:
+                    url = f'https://{pagination_fix[1]}'
             # return all items
             if item_key is None:
                 if 'items' in data:
@@ -347,4 +368,4 @@ class AsRestSession(ClientSession):
                                      if isinstance(v, list)))
             items = data.get(item_key)
             for item in items:
-                yield model.parse_obj(item)
+                yield model(item)
