@@ -6,7 +6,7 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Optional
 
-from pydantic import Field, parse_obj_as
+from pydantic import Field, parse_obj_as, validator
 
 from .access_codes import AccessCodesApi
 from .autoattendant import AutoAttendantApi
@@ -17,6 +17,7 @@ from .callqueue import CallQueueApi
 from .calls import CallsApi
 from .huntgroup import HuntGroupApi
 from .location import TelephonyLocationApi
+from .location.intercept import LocationInterceptApi
 from .organisation_vm import OrganisationVoicemailSettingsAPI
 from .paging import PagingApi
 from .pnc import PrivateNetworkConnectApi
@@ -25,7 +26,7 @@ from .vm_rules import VoicemailRulesApi
 from .voicemail_groups import VoicemailGroupsApi
 from .voiceportal import VoicePortalApi
 from ..api_child import ApiChild
-from ..base import ApiModel, to_camel
+from ..base import ApiModel, to_camel, plus1
 from ..common import UserType, RouteIdentity, NumberState, ValidateExtensionsResponse, ValidatePhoneNumbersResponse
 from ..common.schedules import ScheduleApi, ScheduleApiBase
 from ..person_settings.permissions_out import OutgoingPermissionsApi
@@ -35,7 +36,7 @@ __all__ = ['OwnerType', 'NumberLocation', 'NumberOwner', 'NumberListPhoneNumberT
            'NumberListPhoneNumber',
            'NumberType', 'NumberDetails', 'UCMProfile',
            'TestCallRoutingResult', 'OriginatorType', 'CallSourceType', 'CallSourceInfo', 'DestinationType',
-           'LocationAndNumbers', 'HostedAgentDestination', 'ServiceType', 'HostedFeatureDestination',
+           'LocationAndNumbers', 'HostedUserDestination', 'ServiceType', 'HostedFeatureDestination',
            'TrunkDestination', 'PbxUserDestination', 'PstnNumberDestination', 'VirtualExtensionDestination',
            'RouteListDestination', 'FeatureAccessCodeDestination', 'EmergencyDestination', 'TelephonyApi']
 
@@ -175,8 +176,8 @@ class DestinationType(str, Enum):
     """
     Matching destination type for the call.
     """
-    #: Matching destination is a person or workspace with details in the hostedAgent field.
-    hosted_agent = 'HOSTED_AGENT'
+    #: Matching destination is a person or workspace with details in the hosted_user field.
+    hosted_user = 'HOSTED_USER'
     #: Matching destination is a calling feature like auto-attendant or hunt group with details in the hostedFeature
     #: field.
     hosted_feature = 'HOSTED_FEATURE'
@@ -201,20 +202,24 @@ class DestinationType(str, Enum):
 
 
 class LocationAndNumbers(ApiModel):
+    @validator('phone_number', pre=True)
+    def e164(cls, v):
+        return plus1(v)
+
     location_name: str
     location_id: str
-    phone_number: str
-    extension: str
+    phone_number: Optional[str]
+    extension: Optional[str]
 
 
-class HostedAgentDestination(LocationAndNumbers):
+class HostedUserDestination(LocationAndNumbers):
     """
-    This data object is returned when destinationType is HOSTED_AGENT.
+    This data object is returned when destinationType is HOSTED_USER.
     """
     #: person/workspace's id
-    ha_id: str = Field(alias='id')
+    hu_id: str = Field(alias='id')
     #: Type of agent for call destination.
-    ha_type: UserType = Field(alias='type')
+    hu_type: UserType = Field(alias='type')
     #: Person or workspace's first name.
     first_name: str
     #: Person or workspace's last name.
@@ -233,8 +238,16 @@ class ServiceType(str, Enum):
 
 
 class HostedFeatureDestination(LocationAndNumbers):
-    service_type: ServiceType = Field(alias='tyoe')
+    """
+    This data object is returned when destinationType is HOSTED_FEATURE
+    """
+    service_type: ServiceType
+    service_type1: ServiceType = Field(alias='type')
+    #: service instance name
+    service_name: str
+    #: service instance name
     name: str
+    #: service instance id
     service_instance_id: str = Field(alias='id')
 
 
@@ -258,6 +271,8 @@ class PbxUserDestination(TrunkDestination):
     dial_plan_id: str
     #: the dial pattern that the called string matches
     dial_pattern: str
+    #: the dial pattern that the called string matches (redundant)
+    premises_dial_pattern: str
 
 
 class PstnNumberDestination(TrunkDestination):
@@ -300,9 +315,9 @@ class EmergencyDestination(TrunkDestination):
 
 class TestCallRoutingResult(ApiModel):
     #: Language for call queue.
-    language: str
+    language: Optional[str]
     #: Time zone for the call queue.
-    time_zone: str
+    time_zone: Optional[str]
     #: This data object is only returned when originatorNumber is specified in the request.
     call_source_info: Optional[CallSourceInfo]
     #: Matching destination type for the call.
@@ -310,11 +325,11 @@ class TestCallRoutingResult(ApiModel):
     #: FAC code if destinationType is FAC. The routing address will be returned for all other destination types.
     routing_address: str
     #: Outside access code.
-    outside_access_code: str
+    outside_access_code: Optional[str]
     #: true if the call would be rejected.
     is_rejected: bool
-    #: This data object is returned when destinationType is HOSTED_AGENT.
-    hosted_agent: Optional[HostedAgentDestination]
+    #: This data object is returned when destinationType is HOSTED_USER.
+    hosted_user: Optional[HostedUserDestination] = Field(alias='hostedAgent')
     #: This data object is returned when destinationType is HOSTED_FEATURE.
     hosted_feature: Optional[HostedFeatureDestination]
     #: This data object is returned when destinationType is PBX_USER.
@@ -345,6 +360,8 @@ class TelephonyApi(ApiChild, base='telephony'):
     #: access or authentication codes
     access_codes: AccessCodesApi
     auto_attendant: AutoAttendantApi
+    #: location call intercept settings
+    call_intercept: LocationInterceptApi
     calls: CallsApi
     callpark: CallParkApi
     callpark_extension: CallparkExtensionApi
@@ -360,6 +377,7 @@ class TelephonyApi(ApiChild, base='telephony'):
     prem_pstn: PremisePstnApi
     pnc: PrivateNetworkConnectApi
     schedules: ScheduleApi
+    # location voicemail groups
     voicemail_groups: VoicemailGroupsApi
     voicemail_rules: VoicemailRulesApi
     voiceportal: VoicePortalApi
@@ -368,6 +386,7 @@ class TelephonyApi(ApiChild, base='telephony'):
         super().__init__(session=session)
         self.access_codes = AccessCodesApi(session=session)
         self.auto_attendant = AutoAttendantApi(session=session)
+        self.call_intercept = LocationInterceptApi(session=session)
         self.calls = CallsApi(session=session)
         self.callpark = CallParkApi(session=session)
         self.callpark_extension = CallparkExtensionApi(session=session)
@@ -385,7 +404,7 @@ class TelephonyApi(ApiChild, base='telephony'):
         self.voicemail_rules = VoicemailRulesApi(session=session)
         self.voiceportal = VoicePortalApi(session=session)
 
-    def phone_numbers(self, *, location_id: str = None, phone_number: str = None, available: bool = None,
+    def phone_numbers(self, location_id: str = None, phone_number: str = None, available: bool = None,
                       order: str = None,
                       owner_name: str = None, owner_id: str = None, owner_type: OwnerType = None,
                       extension: str = None, number_type: NumberType = None,
@@ -445,10 +464,11 @@ class TelephonyApi(ApiChild, base='telephony'):
                 value = value.value
                 params[param] = value
         url = self.ep(path='config/numbers')
+        # noinspection PyTypeChecker
         return self.session.follow_pagination(url=url, model=NumberListPhoneNumber, params=params,
                                               item_key='phoneNumbers')
 
-    def phone_number_details(self, *, org_id: str = None) -> NumberDetails:
+    def phone_number_details(self, org_id: str = None) -> NumberDetails:
         """
         get summary (counts) of phone numbers
 
@@ -465,7 +485,7 @@ class TelephonyApi(ApiChild, base='telephony'):
         data = self.get(url, params=params)
         return NumberDetails.parse_obj(data['count'])
 
-    def validate_extensions(self, *, extensions: list[str]) -> ValidateExtensionsResponse:
+    def validate_extensions(self, extensions: list[str]) -> ValidateExtensionsResponse:
         """
         Validate the List of Extensions
 
@@ -506,7 +526,7 @@ class TelephonyApi(ApiChild, base='telephony'):
         data = self.post(url=url, params=params, json=body)
         return ValidatePhoneNumbersResponse.parse_obj(data)
 
-    def ucm_profiles(self, *, org_id: str = None) -> list[UCMProfile]:
+    def ucm_profiles(self, org_id: str = None) -> list[UCMProfile]:
         """
         Read the List of UC Manager Profiles
 
@@ -531,7 +551,7 @@ class TelephonyApi(ApiChild, base='telephony'):
         data = self.get(url, params=params)
         return parse_obj_as(list[UCMProfile], data['callingProfiles'])
 
-    def change_announcement_language(self, *, location_id: str, language_code: str, agent_enabled: bool = None,
+    def change_announcement_language(self, location_id: str, language_code: str, agent_enabled: bool = None,
                                      service_enabled: bool = None, org_id: str = None):
         """
         Change Announcement Language
@@ -587,9 +607,10 @@ class TelephonyApi(ApiChild, base='telephony'):
         params = {to_camel(p): v for i, (p, v) in enumerate(locals().items())
                   if i and v is not None}
         url = self.ep('config/routeChoices')
+        # noinspection PyTypeChecker
         return self.session.follow_pagination(url=url, model=RouteIdentity, params=params, item_key='routeIdentities')
 
-    def test_call_routing(self, *, originator_id: str, originator_type: OriginatorType, destination: str,
+    def test_call_routing(self, originator_id: str, originator_type: OriginatorType, destination: str,
                           originator_number: str = None, org_id: str = None) -> TestCallRoutingResult:
         """
         Validates that an incoming call can be routed.
